% Design the feedback gain matrix for the cart with inverted
% pendulum example. This example follows the procedure
% outlined in Example 2-3 of "Designing Linear Control
% Systems with MATLAB", by K. Ogata
%
% Note that for this model, the state vector is
% [x ; x_dot ; theta_dot ; theta]', so the arrangement of the system
% matrices will be different than in the Ogata example.
%
% System parameters
l = 0.5 ;   % Pendulum length
g = 9.8 ;   % Gravity
m = 0.1 ;   % Pendulum bob mass
M = 2 ;     % Cart mass

% Get the system matrices
[A,B,C,D] = linmod('sysmdl_h',[0,0,0,0],[0])

A1 = [A zeros(4,1) ; -C 0] ;
B1 = [B ; 0] ; 

% Define the controllability matrix M
MM = [B1 A1*B1 A1^2*B1 A1^3*B1 A1^4*B1] ;

% Check the rank of MM, must be 5 if system in completely controllable
rank(MM)

% Obtain the characteristic polynomial
J = [-1+sqrt(3)*i,0,0,0,0;0,-1-sqrt(3)*i,0,0,0;...
     0,0,-5,0,0;0,0,0,-5,0;0,0,0,0,-5] ;
Phi = polyvalm(poly(J),A1) ;

% Get the feedback matrix using Ackermann's formula
KK = [0,0,0,0,1]*(inv(MM))*Phi 
k1 = KK(1)  ; % x gain
k2 = KK(2)  ; % x_dot gain 
k3 = KK(3)  ; % theta_dot gain
k4 = KK(4)  ; % theta gain
KI = -KK(5) ; % error integrator gain

