/* *****************************************************/
/*                        s_xmp4                       */
/* C S-File example that computes y = u(1) + u(2)^2    */
/* Based on MathWorks template file                    */
/* Copyright (c) 1990-96 by The MathWorks, Inc.        */
/* All Rights Reserved                                 */
/* *****************************************************/


#define S_FUNCTION_NAME s_xmp4

#include "simstruc.h"
#include "math.h"

/* *****************************************************/
/*                    mdlInitializeSizes               */
/* *****************************************************/
static void mdlInitializeSizes(SimStruct *S)
{
    /* number of continuous states */
    ssSetNumContStates(    S, 0);
    /* number of discrete states */
    ssSetNumDiscStates(    S, 0);
    /* number of inputs         */
    ssSetNumInputs(        S, 2);
    /* number of outputs */
    ssSetNumOutputs(       S, 1);
    /* direct feedthrough flag */
    ssSetDirectFeedThrough(S, 1);
    /* number of sample times */
    ssSetNumSampleTimes(   S, 1);
    /* number of input arguments */
    ssSetNumSFcnParams(    S, 0);
    /* number of real work vector elements */
    ssSetNumRWork(         S, 0);
    /* number of integer work vector elements*/
    ssSetNumIWork(         S, 0);
    /* number of pointer work vector elements*/
    ssSetNumPWork(         S, 0);   
}

/* *****************************************************/
/*               mdlInitializeSampleTimes              */
/* *****************************************************/
static void mdlInitializeSampleTimes(SimStruct *S)
{
    ssSetSampleTime(S, 0, CONTINUOUS_SAMPLE_TIME);
    ssSetOffsetTime(S, 0, 0.0);
}


/* *****************************************************/
/*                   mdlInitializeConditions           */
/* *****************************************************/
static void mdlInitializeConditions(double *x0,
                                    SimStruct *S)
{
}

/* *****************************************************/
/*                         mdlOutputs                  */
/* *****************************************************/
static void mdlOutputs(double *y, double *x, double *u,
                       SimStruct *S, int tid)
{
  *y = *u + pow(*(u+1),2.0) ;   /* y = u(1) + u(2)^2  */
}

/* *****************************************************/
/*                           mdlUpdate                 */
/* *****************************************************/
static void mdlUpdate(double *x, double *u, SimStruct *S,
                      int tid)
{
}

/* *****************************************************/
/*                           mdlDerivatives            */
/* *****************************************************/
static void mdlDerivatives(double *dx, double *x,
                           double *u, SimStruct *S,
                           int tid)
{
}

/* *****************************************************/
/*                           mdlTerminate              */
/* *****************************************************/
static void mdlTerminate(SimStruct *S)
{
}


#ifdef MATLAB_MEX_FILE   
#include "simulink.c"    
#else
#include "cg_sfun.h"     
#endif
