function strtstpm(varargin)
%************************************************************************
%*                              strtstpm                                *
%************************************************************************
% Callback function for the StartStop subsystem block
% This callback is installed by invoking it with the command
% strtstpm('init_block')
% at the MATLAB prompt, with the appropriate model file open and selected.
% There is an additional callback associated with each button

action = varargin{1}  ;
switch action,
  case 'init_block',
    init_fcn ;                  % Call init_block, located in this M-file
  case 'create_fig',
    if(findobj('UserData',gcb)) % Don't open two for same block
      % Do nothing
    else
      create_fig ;
    end
  case 'close_fig',               % Close if open when model is closed
    h_fig = findobj('UserData',gcb) ;
    if(h_fig)                     % Is the figure for current block open?
      close(h_fig) ;              % If so, close it.
    end
  case 'rename_block',            % Change the name in the figure UserData.
    h_fig = findobj('UserData',gcb) ;
    if(h_fig)                     % Is the figure open?
      set(h_fig,'UserData',gcb) ; % If so, change the name.
    end
  case 'Start_pressed',              % Start button
    Start_Pressed ;
  case 'Stop_pressed',               % Stop button
    Stop_Pressed ;
  case 'start_sim',                  % Something caused sim to start
    Sim_Starting ;
  case 'stop_sim',                   % Something caused sim to stop
    Sim_Stopping ;
end

%************************************************************************
%*                            init_fcn                                  *
%************************************************************************
function init_fcn()
% Configure the subsystem block callbacks
sys = gcs ;
block = [sys,'/StartStop'] ;
set_param(block,'OpenFcn',      'strtstpm create_fig',...
                'ModelCloseFcn','strtstpm close_fig', ...
                'DeleteFcn',    'strtstpm close_fig', ...
                'NameChangeFcn','strtstpm rename_block', ...
                'StartFcn',     'strtstpm start_sim',...
                'StopFcn',      'strtstpm stop_sim') ;

%************************************************************************
%*                            create_fig                                *
%************************************************************************
function create_fig()
% Create the user interface figure and ui controls
h_fig = figure('Position',[555 406 145 44],'Tag','strtstpm',...
              'MenuBar','none','NumberTitle','off', ...
               'Resize','off', ...
               'Name','Sim Control') ;

h_Start_button = uicontrol('Parent',h_fig, ...
'Units','points', ...
'Callback','strtstpm Start_pressed', ...
'Position',[27 4.75 50.25 19.5], ...
'String','Start', ...
'Tag','Start_button', ...
'UserData',bdroot );         % Save current system in Start button userdata

set(h_fig,'UserData',gcb) ; % Save name of current block in
                            % the figure's UserData. This is
                            % used to detect that a strtstpm fig
                            % is already open for the current block,
                            % so that only one instance of the figure
                            % is open at a time.
sim_stat = get_param(bdroot,'SimulationStatus') ;
if(strcmp(sim_stat,'running') | strcmp(sim_stat,'paused'))
  Sim_Starting ;
end

%************************************************************************
%*                            Start_Pressed                             *
%************************************************************************
function Start_Pressed()
% When the Start button is pressed start the simulation
h_fig = gcbf ;
h_Start_button = findobj(h_fig,'Tag','Start_button') ;
cur_sys = get(h_Start_button,'UserData') ;
set_param( cur_sys, 'SimulationCommand', 'start' );

%************************************************************************
%*                            Stop_Pressed                              *
%************************************************************************
function Stop_Pressed()
% When the Stop button is pressed Stop the simulation
h_fig = gcbf ;
h_Start_button = findobj(h_fig,'Tag','Start_button') ;
cur_sys = get(h_Start_button,'UserData') ;
set_param( cur_sys, 'SimulationCommand', 'stop' );

%************************************************************************
%*                            Sim_Starting                              *
%************************************************************************
function Sim_Starting()
% Something started the sim. Make the Start_Stop button read Stop
h_fig = findobj('UserData',gcb) ;
h_Start_button = findobj(h_fig,'Tag','Start_button') ;
set(h_Start_button,'Callback','strtstpm Stop_pressed', ...
'String','Stop') ;

%************************************************************************
%*                            Sim_Stopping                              *
%************************************************************************
function Sim_Stopping()
% Something stopped the sim. Make the Start_Stop button read Start
h_fig = findobj('UserData',gcb) ;
h_Start_button = findobj(h_fig,'Tag','Start_button') ;
set(h_Start_button,'Callback','strtstpm Start_pressed', ...
'String','Start') ;



